@@ -1,8 +1,7 @@
 ## simulate the measurement model
 
-setGeneric("rmeasure",function(object,...)standardGeneric("rmeasure"))
-
-rmeasure.internal <- function (object, x, times, params, .getnativesymbolinfo = TRUE, ...) {
+rmeasure.internal <- function (object, x, times, params,
+                               .getnativesymbolinfo = TRUE, ...) {
   .Call(do_rmeasure,object,x,times,params,.getnativesymbolinfo)
 }
 
