@@ -108,8 +108,6 @@ SEXP iterate_map (SEXP object, SEXP times, SEXP t0, SEXP x0, SEXP params, SEXP g
   lookup_table covariate_table;
   double deltat, t;
 
-  PROTECT(gnsi = duplicate(gnsi)); nprotect++;
-
   deltat = *(REAL(GET_SLOT(object,install("skelmap.delta.t"))));
   t = *(REAL(AS_NUMERIC(t0)));
 
@@ -136,7 +134,6 @@ SEXP iterate_map (SEXP object, SEXP times, SEXP t0, SEXP x0, SEXP params, SEXP g
 
   // extract user-defined function
   PROTECT(fn = pomp_fun_handler(GET_SLOT(object,install("skeleton")),gnsi,&mode)); nprotect++;
-  *(INTEGER(gnsi)) = 0;
 
   // extract 'userdata' as pairlist
   PROTECT(args = VectorToPairList(GET_SLOT(object,install("userdata")))); nprotect++;
@@ -257,11 +254,8 @@ SEXP pomp_desolve_setup (SEXP object, SEXP x0, SEXP params, SEXP gnsi) {
   int *dim;
   int nvars, npars, nreps, ncovars;
 
-  PROTECT(gnsi = duplicate(gnsi)); nprotect++;
-
   // extract user-defined skeleton function
   PROTECT(fn = pomp_fun_handler(GET_SLOT(object,install("skeleton")),gnsi,&mode)); nprotect++;
-  *(INTEGER(gnsi)) = 0;
   // extract 'userdata' as pairlist
   PROTECT(args = VectorToPairList(GET_SLOT(object,install("userdata")))); nprotect++;
 
